==> HostCMS.Free_6.7.tar.gz: modules/site/alias/i18n/en.php <==
<?php
/**
 * Sites.
 *
 * @package HostCMS
 * @subpackage Site
 * @version 6.x
 * @author Hostmake LLC
 * @copyright © 2005-2017 ООО "Хостмэйк" (Hostmake LLC), http://www.hostcms.ru
 */
return array(
	'model_name' => 'Domains',
	'markDeleted_success' => 'Information about domain successfully deleted',
	'markDeleted_error' => 'Error occurred during deleting domain information',
	'setCurrent_success' => 'Current domain set successfully',
	'setCurrent_error' => 'Error occurred during setting up current domain',
	'edit_success' => 'Domain information modified successfully!',
	'site_add_domen_error' => 'Domain information has not been added!',
	'edit_error' => 'Domain information has not been modified!',
	'site_add_domen_success' => 'Domain information added successfully!',
	'site_add_domen_form_title' => 'Add domain information',
	'site_edit_domen_form_title' => 'Edit domain information',
	'site_link_sites' => 'Websites',
	'site_link_site_name' => 'Website "%s"',
	'site_parameters' => 'Parameters',
	'name' => '<acronym title="Domain (without http://, e.g., site.ru)">Domain (without http://)</acronym>',
	'current' => '<acronym title="Main domain is used in a number of system modules and in administration section. Used to generate direct links">Main domain</acronym>',
	'id' => 'Id',
	'site_id' => 'Site id',
	'site_link_site' => 'Website',
	'error_current_alias' => '	Attention! Website should have a main domain!',
	'site_link_domens' => 'Domain',
	'site_link_domen_add' => 'Add',
	'site_show_domen_title' => 'Domains of website "%s"',
	'constant_check_error' => 'Necessary constants not found; please fill in form fields Websites &#8594; Settings &#8594; Registration data',
	'server_error_respond_0' => 'Unknown error!',
	'server_error_respond_1' => 'Server configuration has been changed; you cannot get a key. Please contact administrator.',
	'server_error_respond_2' => 'User not found. Please ensure that you specified a correct login in your registration data in section Websites.',
	'server_error_respond_3' => 'Order not found. This order may belong to another user. Please ensure that you specified a correct login in your registration data in section Websites.',
	'server_error_respond_4' => 'HostCMS system not found. Please try to request key once more. Please pay attention &mdash; that the management system should be available on the main domain of the current website. Specify a main domain in the domains list.',
	'server_error_respond_5' => 'Invalid domain name.',
	'server_error_respond_6' => 'You cannot get keys, please contact administrator.',
	'server_error_respond_10' => 'Error 10. Please contact the support.',
	'server_error_respond_data' => 'Error while processing data.',
	'site_delete_domens_message' => 'Domains deleted successfully!',
	'getKey_success' => 'Key received successfully.',
	'delete_success' => 'Item deleted successfully!',
	'undelete_success' => 'Item restored successfully!',
	'redirect' => '<acronym title="Use 301 redirect to base domain">Redirect</acronym>',
	'setRedirect_success' => 'Information has been saved',
);

==> HostCMS.Free_7.0.tar.gz: modules/site/alias/i18n/en.php <==
<?php

return array(
	'model_name' => 'Domains',
	'markDeleted_success' => 'Information about domain successfully deleted',
	'markDeleted_error' => 'Error occurred during deleting domain information',
	'setCurrent_success' => 'Current domain set successfully',
	'setCurrent_error' => 'Error occurred during setting up current domain',
	'edit_success' => 'Domain information modified successfully!',
	'site_add_domen_error' => 'Domain information has not been added!',
	'edit_error' => 'Domain information has not been modified!',
	'site_add_domen_success' => 'Domain information added successfully!',
	'site_add_domen_form_title' => 'Add domain information',
	'site_edit_domen_form_title' => 'Edit domain information',
	'site_link_sites' => 'Websites',
	'site_link_site_name' => 'Website "%s"',
	'site_parameters' => 'Parameters',
	'name' => '<acronym title="Domain (without http://, e.g., site.ru)">Domain (without http://)</acronym>',
	'current' => '<acronym title="Main domain is used in a number of system modules and in administration section. Used to generate direct links">Main domain</acronym>',
	'id' => 'ID',
	'site_id' => 'Site id',
	'site_link_site' => 'Website',
	'error_current_alias' => '	Attention! Website should have a main domain!',
	'site_link_domens' => 'Domain',
	'site_link_domen_add' => 'Add',
	'site_show_domen_title' => 'Domains of website "%s"',
	'constant_check_error' => 'Necessary constants not found; please fill in form fields Websites &#8594; Settings &#8594; Registration data',
	'server_error_respond_0' => 'Unknown error!',
	'server_error_respond_1' => 'Server configuration has been changed; you cannot get a key. Please contact administrator.',
	'server_error_respond_2' => 'User not found. Please ensure that you specified a correct login in your registration data in section Websites.',
	'server_error_respond_3' => 'Order not found. This order may belong to another user. Please ensure that you specified a correct login in your registration data in section Websites.',
	'server_error_respond_4' => 'HostCMS system not found. Please try to request key once more.
	<br />Please pay attention &mdash; that the management system should be available on the main domain of the current website. Specify a main domain in the domains list.
	<br /><b>If your site is running over HTTPS, then the site must have the HTTPS option set</b>.',
	'server_error_respond_5' => 'Invalid domain name.',
	'server_error_respond_6' => 'You cannot get keys, please contact administrator.',
	'server_error_respond_10' => 'Error 10. Please contact the support.',
	'server_error_respond_data' => 'Error while processing data.',
	'site_delete_domens_message' => 'Domains deleted successfully!',
	'getKey_success' => 'Key received successfully!',
	'delete_success' => 'Item deleted successfully!',
	'undelete_success' => 'Item restored successfully!',
	'redirect' => '<acronym title="Use 301 redirect to base domain">Redirect</acronym>',
	'setRedirect_success' => 'Information has been saved',
	'get_key' => 'Get key',
	'select_site' => 'Site',
	'move_success' => 'Domain moved successfully!',
);
